==> mhkit-0.3.1.tar.gz: mhkit-0.3.1/README.md <==
![](figures/logo.png) MHKiT-Python
=====================================

[![Build Status](https://travis-ci.org/MHKiT-Software/MHKiT-Python.svg?branch=master)](https://travis-ci.org/MHKiT-Software/MHKiT-Python)
[![Coverage Status](https://coveralls.io/repos/github/MHKiT-Software/MHKiT-Python/badge.svg?branch=master)](https://coveralls.io/github/MHKiT-Software/MHKiT-Python?branch=master)
[![Downloads](https://pepy.tech/badge/mhkit)](https://pepy.tech/project/mhkit)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3924683.svg)](https://doi.org/10.5281/zenodo.3924683)


MHKiT-Python is a Python package designed for marine renewable energy applications to assist in 
data processing and visualization.  The software package include functionality for:

* Data processing
* Data visualization
* Data quality control
* Resource assessment
* Device performance
* Device loads

Documentation
------------------
MHKiT-Python documentation includes overview information, installation instructions, API documentation, and examples.
See the [MHKiT documentation](https://mhkit-software.github.io/MHKiT) for more information.

Installation
------------------------
MHKiT-Python requires Python (3.6 or 3.7) along with several Python 
package dependencies.  MHKiT-Python can be installed from PyPI using the command ``pip install mhkit``.
See [installation instructions](https://mhkit-software.github.io/MHKiT/installation.html) for more information.

Copyright and license
------------------------
MHKiT-Python is copyright through the National Renewable Energy Laboratory, 
Pacific Northwest National Laboratory, and Sandia National Laboratories. 
The software is distributed under the Revised BSD License.
See [copyright and license](LICENSE.md) for more information.

==> mhkit-0.4.0.tar.gz: mhkit-0.4.0/README.md <==
![](figures/logo.png) MHKiT-Python
=====================================

[![Build Status](https://travis-ci.org/MHKiT-Software/MHKiT-Python.svg?branch=master)](https://travis-ci.org/MHKiT-Software/MHKiT-Python)
[![Coverage Status](https://coveralls.io/repos/github/MHKiT-Software/MHKiT-Python/badge.svg?branch=master)](https://coveralls.io/github/MHKiT-Software/MHKiT-Python?branch=master)
[![Downloads](https://pepy.tech/badge/mhkit)](https://pepy.tech/project/mhkit)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3924683.svg)](https://doi.org/10.5281/zenodo.3924683)


MHKiT-Python is a Python package designed for marine renewable energy applications to assist in 
data processing and visualization.  The software package include functionality for:

* Data processing
* Data visualization
* Data quality control
* Resource assessment
* Device performance
* Device loads

Documentation
------------------
MHKiT-Python documentation includes overview information, installation instructions, API documentation, and examples.
See the [MHKiT documentation](https://mhkit-software.github.io/MHKiT) for more information.

Installation
------------------------
MHKiT-Python requires Python (3.7, 3.8, or 3.9) along with several Python 
package dependencies.  MHKiT-Python can be installed from PyPI using the command ``pip install mhkit``.
See [installation instructions](https://mhkit-software.github.io/MHKiT/installation.html) for more information.

Copyright and license
------------------------
MHKiT-Python is copyright through the National Renewable Energy Laboratory, 
Pacific Northwest National Laboratory, and Sandia National Laboratories. 
The software is distributed under the Revised BSD License.
See [copyright and license](LICENSE.md) for more information.
